@@ -103,6 +103,9 @@ class IVector:
             raise TypeError(f"Object of type [{type(other)}] cannot be multiplied to {type(self)}")
 
         new_vector = self.unit()
+        if new_vector is None:
+            return Vector2(0, 0)
+
         for ii in new_vector.coords:
             new_vector.coords[ii] = new_vector.coords[ii] * self.length() * other
 
